from . import API


class ComputeAPI(API):

    base_url = 'https://api.cloud.online.net'
